Colorbundle
===========

|PyPI| |GitHub Issues|

Template filters for extracting colours from an image.

Installation
------------

.. code:: sh

    pip install django-colorbundle

Changelog
---------
0.1.2 — 2017-04-10
******************
- **Fix:** Add dependency version number
- **Fix:** Correct dependency name

0.1.0
*****
- Initial release

.. |PyPI| image:: https://img.shields.io/pypi/v/django-colorbundle.svg?style=flat-square
   :target: https://pypi.python.org/pypi/django-colorbundle/
.. |GitHub Issues| image:: https://img.shields.io/github/issues/stormwarning/django-colorbundle.svg?style=flat-square
   :target: https://github.com/stormwarning/django-colorbundle/issues
